threejs: JavaScript library to display 3D graphics in the browser
=================================================================

Description
-----------

Three.js is a JavaScript library to display 3D graphics in the browser.

License
-------

MIT License


Upstream Contact
----------------

Home page: http://threejs.org

Dependencies
------------

None.


Special Update/Build Instructions
---------------------------------

None.
